@@ -39,6 +39,31 @@ if($page == 'overview')
 	$log->logAction(USR_ACTION, LOG_NOTICE, "viewed customer_extras");
 	eval("echo \"" . getTemplate("extras/extras") . "\";");
 }
+elseif($page == 'backup')
+{
+    $log->logAction(USR_ACTION, LOG_NOTICE, "viewed customer_extras_backup");
+
+    $result = $db->query("SELECT `backup_enabled` FROM `" . TABLE_PANEL_CUSTOMERS . "` WHERE `customerid`='" . (int)$userinfo['customerid'] . "'");
+    $row = $db->fetch_array($result);
+
+    $backup_enabled = makeyesno('backup_enabled', '1', '0', $row['backup_enabled']);
+
+    if(isset($_POST['send']) && $_POST['send'] == 'send'){
+	$backup_enabled = ($_POST['backup_enabled'] == '1' ? '1' : '0');
+	$backup_ftp_enabled = ($_POST['backup_ftp_enabled'] == '1' ? '1' : '0');
+	
+        $db->query("UPDATE `" . TABLE_PANEL_CUSTOMERS . "` SET `backup_enabled`='" . $backup_enabled . "' WHERE `customerid`='" . (int)$userinfo['customerid'] . "'");
+	redirectTo($filename, Array('page' => $page, 's' => $s));
+    }
+
+    $backup_data = include_once dirname(__FILE__).'/lib/formfields/customer/extras/formfield.backup.php';
+	$backup_form = htmlform::genHTMLForm($backup_data);
+
+	$title = $backup_data['backup']['title'];
+	$image = $backup_data['backup']['image'];
+    
+    eval("echo \"" . getTemplate("extras/backup") . "\";");
+}
 elseif($page == 'htpasswds')
 {
 	if($action == '')
@@ -368,9 +393,9 @@ elseif($page == 'htaccess')
 		else
 		{
 			$pathSelect = makePathfield($userinfo['documentroot'], $userinfo['guid'], $userinfo['guid'], $settings['panel']['pathedit']);
-			$options_indexes = makeyesno('options_indexes', '1', '0', '0');
+			#$options_indexes = makeyesno('options_indexes', '1', '0', '0');
 			$cperlenabled = customerHasPerlEnabled($userinfo['customerid']);
-			$options_cgi = makeyesno('options_cgi', '1', '0', '0');
+			#$options_cgi = makeyesno('options_cgi', '1', '0', '0');
 
 			$htaccess_add_data = include_once dirname(__FILE__).'/lib/formfields/customer/extras/formfield.htaccess_add.php';
 			$htaccess_add_form = htmlform::genHTMLForm($htaccess_add_data);
@@ -435,9 +460,9 @@ elseif($page == 'htaccess')
 				$result['error404path'] = $result['error404path'];
 				$result['error403path'] = $result['error403path'];
 				$result['error500path'] = $result['error500path'];
-				$options_indexes = makeyesno('options_indexes', '1', '0', $result['options_indexes']);
+				#$options_indexes = makeyesno('options_indexes', '1', '0', $result['options_indexes']);
 				$cperlenabled = customerHasPerlEnabled($userinfo['customerid']);
-				$options_cgi = makeyesno('options_cgi', '1', '0', $result['options_cgi']);
+				#$options_cgi = makeyesno('options_cgi', '1', '0', $result['options_cgi']);
 				$result = htmlentities_array($result);
 
 				$htaccess_edit_data = include_once dirname(__FILE__).'/lib/formfields/customer/extras/formfield.htaccess_edit.php';
