@@ -268,7 +268,7 @@ elseif($page == 'accounts')
 					}
 				}
 
-				$sendinfomail = makeyesno('sendinfomail', '1', '0', '0');
+				#$sendinfomail = makeyesno('sendinfomail', '1', '0', '0');
 
 				$ftp_add_data = include_once dirname(__FILE__).'/lib/formfields/customer/ftp/formfield.ftp_add.php';
 				$ftp_add_form = htmlform::genHTMLForm($ftp_add_data);
@@ -324,6 +324,7 @@ elseif($page == 'accounts')
 						if(!file_exists($path))
 						{
 							mkDirWithCorrectOwnership($userinfo['documentroot'], $path, $result['uid'], $result['gid']);
+							inserttask(5); /* Let the cronjob do the rest */
 						}
 
 						$log->logAction(USR_ACTION, LOG_INFO, "updated ftp-account homdir for '" . $result['username'] . "'");
