@@ -1534,3 +1534,11 @@ if(isFroxlorVersion('0.9.20-svn2'))
 
 	updateToVersion('0.9.20');
 }
+
+if(isFroxlorVersion('0.9.20'))
+{
+	showUpdateStep("Updating from 0.9.20 to 0.9.20.1");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.20.1');
+}
