@@ -36,18 +36,29 @@ return array(
 					),
 					'createstdsubdomain' => array(
 						'label' => $lng['admin']['stdsubdomain_add'].'?',
-						'type' => 'yesno',
-						'yesno_var' => $createstdsubdomain
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array(($result['standardsubdomain'] != '0') ? '1' : '0')
 					),
 					'deactivated' => array(
 						'label' => $lng['admin']['deactivated_user'],
-						'type' => 'yesno',
-						'yesno_var' => $deactivated
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array($result['deactivated'])
 					),
 					'new_customer_password' => array(
 						'label' => $lng['login']['password'].'&nbsp;('.$lng['panel']['emptyfornochanges'].')',
 						'type' => 'password'
 					),
+					'new_customer_password_suggestion' => array(
+						'label' => $lng['customer']['generated_pwd'],
+						'type' => 'text',
+						'value' => generatePassword(),
+					),
 					'def_language' => array(
 						'label' => $lng['login']['language'],
 						'type' => 'select',
@@ -186,14 +197,20 @@ return array(
 					),
 					'email_imap' => array(
 						'label' => $lng['customer']['email_imap'],
-						'type' => 'yesno',
-						'yesno_var' => $email_imap,
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array($result['imap']),
 						'mandatory' => true
 					),
 					'email_pop3' => array(
 						'label' => $lng['customer']['email_pop3'],
-						'type' => 'yesno',
-						'yesno_var' => $email_pop3,
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array($result['pop3']),
 						'mandatory' => true
 					),
 					'ftps' => array(
@@ -221,13 +238,24 @@ return array(
 					),
 					'phpenabled' => array(
 						'label' => $lng['admin']['phpenabled'].'?',
-						'type' => 'yesno',
-						'yesno_var' => $phpenabled
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array($result['phpenabled'])
 					),
 					'perlenabled' => array(
 						'label' => $lng['admin']['perlenabled'].'?',
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array($result['perlenabled'])
+					),
+					'backup_allowed' => array(
+						'label' => $lng['backup_allowed'].'?',
 						'type' => 'yesno',
-						'yesno_var' => $perlenabled
+						'yesno_var' => $backup_allowed
 					),
 					'number_of_aps_packages' => array(
 						'label' => $lng['aps']['numberofapspackages'],
