@@ -55,8 +55,11 @@ return array(
 					),
 					'caneditdomain' => array(
 						'label' => $lng['admin']['domain_edit'],
-						'type' => 'yesno',
-						'yesno_var' => $caneditdomain
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array('1')
 					),
 					'add_date' => array(
 						'label' => $lng['domains']['add_date'],
@@ -91,14 +94,20 @@ return array(
 					'ssl' => array(
 						'visible' => ($settings['system']['use_ssl'] == '1' ? ($ssl_ipsandports != '' ? true : false) : false),
 						'label' => 'SSL',
-						'type' => 'yesno',
-						'yesno_var' => $ssl
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array()
 					),
 					'ssl_redirect' => array(
 						'visible' => ($settings['system']['use_ssl'] == '1' ? ($ssl_ipsandports != '' ? true : false) : false),
 						'label' => 'SSL Redirect',
-						'type' => 'yesno',
-						'yesno_var' => $ssl_redirect
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array()
 					),
 					'ssl_ipandport' => array(
 						'visible' => ($settings['system']['use_ssl'] == '1' ? ($ssl_ipsandports != '' ? true : false) : false),
@@ -114,13 +123,19 @@ return array(
 					),
 					'wwwserveralias' => array(
 						'label' => $lng['admin']['wwwserveralias'],
-						'type' => 'yesno',
-						'yesno_var' => $wwwserveralias
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array('1')
 					),
 					'speciallogfile' => array(
 						'label' => 'Speciallogfile',
-						'type' => 'yesno',
-						'yesno_var' => $speciallogfile
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array()
 					),
 					'specialsettings' => array(
 						'visible' => ($userinfo['change_serversettings'] == '1' ? true : false),
@@ -140,13 +155,19 @@ return array(
 				'fields' => array(
 					'openbasedir' => array(
 						'label' => 'OpenBasedir',
-						'type' => 'yesno',
-						'yesno_var' => $openbasedir
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array('1')
 					),
 					'safemode' => array(
 						'label' => 'Safemode',
-						'type' => 'yesno',
-						'yesno_var' => $safemode
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array('1')
 					),
 					'phpsettingid' => array(
 						'visible' => ((int)$settings['system']['mod_fcgid'] == 1 ? true : false),
@@ -173,8 +194,11 @@ return array(
 				'fields' => array(
 					'isbinddomain' => array(
 						'label' => 'Nameserver',
-						'type' => 'yesno',
-						'yesno_var' => $isbinddomain
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array('1')
 					),
 					'zonefile' => array(
 						'label' => 'Zonefile',
@@ -189,13 +213,19 @@ return array(
 				'fields' => array(
 					'isemaildomain' => array(
 						'label' => $lng['admin']['emaildomain'],
-						'type' => 'yesno',
-						'yesno_var' => $isemaildomain
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array('1')
 					),
 					'email_only' => array(
 						'label' => $lng['admin']['email_only'],
-						'type' => 'yesno',
-						'yesno_var' => $email_only
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array()
 					),
 					'subcanemaildomain' => array(
 						'label' => $lng['admin']['subdomainforemail'],
@@ -205,8 +235,11 @@ return array(
 					'dkim' => array(
 						'visible' => ($settings['dkim']['use_dkim'] == '1' ? true : false),
 						'label' => 'DomainKeys',
-						'type' => 'yesno',
-						'yesno_var' => $dkim
+						'type' => 'checkbox',
+						'values' => array(
+										array ('label' => $lng['panel']['yes'], 'value' => '1')
+									),
+						'value' => array('1')
 					)
 				)
 			)
