@@ -39,6 +39,11 @@ return array(
 						'label' => $lng['login']['password'],
 						'desc' => $lng['ftp']['editpassdescription'],
 						'type' => 'password',
+					),
+					'ftp_password_suggestion' => array(
+						'label' => $lng['customer']['generated_pwd'],
+						'type' => 'text',
+						'value' => generatePassword(),
 					)
 				)
 			)
