@@ -974,7 +974,7 @@ class apache
 						&& isset($row_diroptions['options_cgi'])
 						&& $row_diroptions['options_cgi'] == '1')
 					{
-						$this->diroptions_data[$diroptions_filename].= ' ExecCGI -MultiViews +SymLinksIfOwnerMatch +FollowSysLinks'."\n";
+						$this->diroptions_data[$diroptions_filename].= ' ExecCGI -MultiViews +SymLinksIfOwnerMatch +FollowSymLinks'."\n";
 					} else {
 						$this->diroptions_data[$diroptions_filename].= "\n";
 					}
@@ -991,7 +991,7 @@ class apache
 						&& isset($row_diroptions['options_cgi'])
 						&& $row_diroptions['options_cgi'] == '1')
 					{
-						$this->diroptions_data[$diroptions_filename].= ' ExecCGI -MultiViews +SymLinksIfOwnerMatch +FollowSysLinks'."\n";
+						$this->diroptions_data[$diroptions_filename].= ' ExecCGI -MultiViews +SymLinksIfOwnerMatch +FollowSymLinks'."\n";
 					} else {
 						$this->diroptions_data[$diroptions_filename].= "\n";
 					}
